Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/monodevelop.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLluis Sanchez <lluis@xamarin.com>2012-10-04 20:54:36 +0400
committerLluis Sanchez <lluis@xamarin.com>2012-10-04 20:56:17 +0400
commit9fd90d02add94c01a77b3e002312b428026dac2b (patch)
tree504ca0397d057f27f47c31183876d831e9ec9a73 /main/src/addins/MonoDevelop.Debugger/gtk-gui
parenta04e3d2f73135f097a0b3087a178c13a9ee4e1f7 (diff)
Improved the Exception Caught dialog
The exception dialog is now a widget embedded in the text editor.
Diffstat (limited to 'main/src/addins/MonoDevelop.Debugger/gtk-gui')
-rw-r--r--main/src/addins/MonoDevelop.Debugger/gtk-gui/MonoDevelop.Debugger.ExceptionCaughtWidget.cs (renamed from main/src/addins/MonoDevelop.Debugger/gtk-gui/MonoDevelop.Debugger.ExceptionCaughtDialog.cs)87
-rw-r--r--main/src/addins/MonoDevelop.Debugger/gtk-gui/gui.stetic43
2 files changed, 37 insertions, 93 deletions
diff --git a/main/src/addins/MonoDevelop.Debugger/gtk-gui/gui.stetic b/main/src/addins/MonoDevelop.Debugger/gtk-gui/gui.stetic
index ecac6b7a4b..d88e40a6e8 100644
--- a/main/src/addins/MonoDevelop.Debugger/gtk-gui/gui.stetic
+++ b/main/src/addins/MonoDevelop.Debugger/gtk-gui/gui.stetic
@@ -1760,14 +1760,10 @@
</widget>
</child>
</widget>
- <widget class="Gtk.Dialog" id="MonoDevelop.Debugger.ExceptionCaughtDialog" design-size="541 358">
+ <widget class="Gtk.Bin" id="MonoDevelop.Debugger.ExceptionCaughtWidget" design-size="541 358">
<property name="MemberName" />
<property name="Visible">False</property>
- <property name="Title" translatable="yes">Exception Caught</property>
- <property name="WindowPosition">CenterOnParent</property>
- <property name="Buttons">1</property>
- <property name="HelpButton">False</property>
- <child internal-child="VBox">
+ <child>
<widget class="Gtk.VBox" id="dialog1_VBox">
<property name="MemberName" />
<property name="BorderWidth">2</property>
@@ -1782,7 +1778,6 @@
<property name="Xalign">0</property>
<property name="LabelProp">&lt;b&gt;Exception&lt;/b&gt; has been thrown</property>
<property name="UseMarkup">True</property>
- <property name="Selectable">True</property>
</widget>
<packing>
<property name="Position">0</property>
@@ -1798,7 +1793,6 @@
<property name="Xalign">0</property>
<property name="LabelProp">test test test test test test test test test test test test test test test test test test test test test test test test test test test test test test test test</property>
<property name="Wrap">True</property>
- <property name="Selectable">True</property>
</widget>
<packing>
<property name="Position">1</property>
@@ -1816,14 +1810,13 @@
<widget class="Gtk.ScrolledWindow" id="GtkScrolledWindow1">
<property name="MemberName" />
<property name="ShadowType">In</property>
+ <property name="BorderWidth">3</property>
<child>
- <widget class="Gtk.TextView" id="stackTextView">
+ <widget class="Gtk.TreeView" id="treeStack">
<property name="MemberName" />
<property name="CanFocus">True</property>
<property name="ShowScrollbars">True</property>
- <property name="Editable">False</property>
- <property name="CursorVisible">False</property>
- <property name="Text" translatable="yes" />
+ <property name="HeadersVisible">False</property>
</widget>
</child>
</widget>
@@ -1884,32 +1877,6 @@
</child>
</widget>
</child>
- <child internal-child="ActionArea">
- <widget class="Gtk.HButtonBox" id="dialog1_ActionArea">
- <property name="MemberName" />
- <property name="Spacing">10</property>
- <property name="BorderWidth">5</property>
- <property name="Size">1</property>
- <property name="LayoutStyle">End</property>
- <child>
- <widget class="Gtk.Button" id="buttonOk">
- <property name="MemberName" />
- <property name="CanDefault">True</property>
- <property name="CanFocus">True</property>
- <property name="UseStock">True</property>
- <property name="Type">StockItem</property>
- <property name="StockId">gtk-close</property>
- <property name="ResponseId">-7</property>
- <signal name="Clicked" handler="OnButtonOkClicked" />
- <property name="label">gtk-close</property>
- </widget>
- <packing>
- <property name="Expand">False</property>
- <property name="Fill">False</property>
- </packing>
- </child>
- </widget>
- </child>
</widget>
<widget class="Gtk.Dialog" id="MonoDevelop.Debugger.Viewers.ValueVisualizerDialog" design-size="628 433">
<property name="MemberName" />
diff --git a/main/src/addins/MonoDevelop.Debugger/gtk-gui/MonoDevelop.Debugger.ExceptionCaughtDialog.cs b/main/src/addins/MonoDevelop.Debugger/gtk-gui/MonoDevelop.Debugger.ExceptionCaughtWidget.cs
index 816359d44b..2d823ee259 100644
--- a/main/src/addins/MonoDevelop.Debugger/gtk-gui/MonoDevelop.Debugger.ExceptionCaughtDialog.cs
+++ b/main/src/addins/MonoDevelop.Debugger/gtk-gui/MonoDevelop.Debugger.ExceptionCaughtWidget.cs
@@ -2,31 +2,30 @@
// This file has been generated by the GUI designer. Do not modify.
namespace MonoDevelop.Debugger
{
- public partial class ExceptionCaughtDialog
+ public partial class ExceptionCaughtWidget
{
+ private global::Gtk.VBox dialog1_VBox;
private global::Gtk.VBox vbox2;
private global::Gtk.Label labelType;
private global::Gtk.Label labelMessage;
private global::Gtk.Notebook notebook1;
private global::Gtk.ScrolledWindow GtkScrolledWindow1;
- private global::Gtk.TextView stackTextView;
+ private global::Gtk.TreeView treeStack;
private global::Gtk.Label label2;
private global::Gtk.ScrolledWindow GtkScrolledWindow;
private global::MonoDevelop.Debugger.ObjectValueTreeView valueView;
private global::Gtk.Label page1;
- private global::Gtk.Button buttonOk;
protected virtual void Build ()
{
global::Stetic.Gui.Initialize (this);
- // Widget MonoDevelop.Debugger.ExceptionCaughtDialog
- this.Name = "MonoDevelop.Debugger.ExceptionCaughtDialog";
- this.Title = global::Mono.Unix.Catalog.GetString ("Exception Caught");
- this.WindowPosition = ((global::Gtk.WindowPosition)(4));
- // Internal child MonoDevelop.Debugger.ExceptionCaughtDialog.VBox
- global::Gtk.VBox w1 = this.VBox;
- w1.Name = "dialog1_VBox";
- w1.BorderWidth = ((uint)(2));
+ // Widget MonoDevelop.Debugger.ExceptionCaughtWidget
+ global::Stetic.BinContainer.Attach (this);
+ this.Name = "MonoDevelop.Debugger.ExceptionCaughtWidget";
+ // Container child MonoDevelop.Debugger.ExceptionCaughtWidget.Gtk.Container+ContainerChild
+ this.dialog1_VBox = new global::Gtk.VBox ();
+ this.dialog1_VBox.Name = "dialog1_VBox";
+ this.dialog1_VBox.BorderWidth = ((uint)(2));
// Container child dialog1_VBox.Gtk.Box+BoxChild
this.vbox2 = new global::Gtk.VBox ();
this.vbox2.Name = "vbox2";
@@ -38,12 +37,11 @@ namespace MonoDevelop.Debugger
this.labelType.Xalign = 0F;
this.labelType.LabelProp = "<b>Exception</b> has been thrown";
this.labelType.UseMarkup = true;
- this.labelType.Selectable = true;
this.vbox2.Add (this.labelType);
- global::Gtk.Box.BoxChild w2 = ((global::Gtk.Box.BoxChild)(this.vbox2 [this.labelType]));
- w2.Position = 0;
- w2.Expand = false;
- w2.Fill = false;
+ global::Gtk.Box.BoxChild w1 = ((global::Gtk.Box.BoxChild)(this.vbox2 [this.labelType]));
+ w1.Position = 0;
+ w1.Expand = false;
+ w1.Fill = false;
// Container child vbox2.Gtk.Box+BoxChild
this.labelMessage = new global::Gtk.Label ();
this.labelMessage.WidthRequest = 500;
@@ -51,12 +49,11 @@ namespace MonoDevelop.Debugger
this.labelMessage.Xalign = 0F;
this.labelMessage.LabelProp = "test test test test test test test test test test test test test test test test test test test test test test test test test test test test test test test test";
this.labelMessage.Wrap = true;
- this.labelMessage.Selectable = true;
this.vbox2.Add (this.labelMessage);
- global::Gtk.Box.BoxChild w3 = ((global::Gtk.Box.BoxChild)(this.vbox2 [this.labelMessage]));
- w3.Position = 1;
- w3.Expand = false;
- w3.Fill = false;
+ global::Gtk.Box.BoxChild w2 = ((global::Gtk.Box.BoxChild)(this.vbox2 [this.labelMessage]));
+ w2.Position = 1;
+ w2.Expand = false;
+ w2.Fill = false;
// Container child vbox2.Gtk.Box+BoxChild
this.notebook1 = new global::Gtk.Notebook ();
this.notebook1.CanFocus = true;
@@ -66,13 +63,13 @@ namespace MonoDevelop.Debugger
this.GtkScrolledWindow1 = new global::Gtk.ScrolledWindow ();
this.GtkScrolledWindow1.Name = "GtkScrolledWindow1";
this.GtkScrolledWindow1.ShadowType = ((global::Gtk.ShadowType)(1));
+ this.GtkScrolledWindow1.BorderWidth = ((uint)(3));
// Container child GtkScrolledWindow1.Gtk.Container+ContainerChild
- this.stackTextView = new global::Gtk.TextView ();
- this.stackTextView.CanFocus = true;
- this.stackTextView.Name = "stackTextView";
- this.stackTextView.Editable = false;
- this.stackTextView.CursorVisible = false;
- this.GtkScrolledWindow1.Add (this.stackTextView);
+ this.treeStack = new global::Gtk.TreeView ();
+ this.treeStack.CanFocus = true;
+ this.treeStack.Name = "treeStack";
+ this.treeStack.HeadersVisible = false;
+ this.GtkScrolledWindow1.Add (this.treeStack);
this.notebook1.Add (this.GtkScrolledWindow1);
// Notebook tab
this.label2 = new global::Gtk.Label ();
@@ -98,8 +95,8 @@ namespace MonoDevelop.Debugger
this.valueView.CompactView = false;
this.GtkScrolledWindow.Add (this.valueView);
this.notebook1.Add (this.GtkScrolledWindow);
- global::Gtk.Notebook.NotebookChild w7 = ((global::Gtk.Notebook.NotebookChild)(this.notebook1 [this.GtkScrolledWindow]));
- w7.Position = 1;
+ global::Gtk.Notebook.NotebookChild w6 = ((global::Gtk.Notebook.NotebookChild)(this.notebook1 [this.GtkScrolledWindow]));
+ w6.Position = 1;
// Notebook tab
this.page1 = new global::Gtk.Label ();
this.page1.Name = "page1";
@@ -107,36 +104,16 @@ namespace MonoDevelop.Debugger
this.notebook1.SetTabLabel (this.GtkScrolledWindow, this.page1);
this.page1.ShowAll ();
this.vbox2.Add (this.notebook1);
- global::Gtk.Box.BoxChild w8 = ((global::Gtk.Box.BoxChild)(this.vbox2 [this.notebook1]));
- w8.Position = 2;
- w1.Add (this.vbox2);
- global::Gtk.Box.BoxChild w9 = ((global::Gtk.Box.BoxChild)(w1 [this.vbox2]));
- w9.Position = 0;
- // Internal child MonoDevelop.Debugger.ExceptionCaughtDialog.ActionArea
- global::Gtk.HButtonBox w10 = this.ActionArea;
- w10.Name = "dialog1_ActionArea";
- w10.Spacing = 10;
- w10.BorderWidth = ((uint)(5));
- w10.LayoutStyle = ((global::Gtk.ButtonBoxStyle)(4));
- // Container child dialog1_ActionArea.Gtk.ButtonBox+ButtonBoxChild
- this.buttonOk = new global::Gtk.Button ();
- this.buttonOk.CanDefault = true;
- this.buttonOk.CanFocus = true;
- this.buttonOk.Name = "buttonOk";
- this.buttonOk.UseStock = true;
- this.buttonOk.UseUnderline = true;
- this.buttonOk.Label = "gtk-close";
- this.AddActionWidget (this.buttonOk, -7);
- global::Gtk.ButtonBox.ButtonBoxChild w11 = ((global::Gtk.ButtonBox.ButtonBoxChild)(w10 [this.buttonOk]));
- w11.Expand = false;
- w11.Fill = false;
+ global::Gtk.Box.BoxChild w7 = ((global::Gtk.Box.BoxChild)(this.vbox2 [this.notebook1]));
+ w7.Position = 2;
+ this.dialog1_VBox.Add (this.vbox2);
+ global::Gtk.Box.BoxChild w8 = ((global::Gtk.Box.BoxChild)(this.dialog1_VBox [this.vbox2]));
+ w8.Position = 0;
+ this.Add (this.dialog1_VBox);
if ((this.Child != null)) {
this.Child.ShowAll ();
}
- this.DefaultWidth = 541;
- this.DefaultHeight = 358;
this.Hide ();
- this.buttonOk.Clicked += new global::System.EventHandler (this.OnButtonOkClicked);
}
}
}